---
name: verify-x509 issue
about: All verify-x509 issues
title: ''
labels: ''
assignees: ''

---

<!--

Thank you for your interest in verify-x509. If you want to report an issue or make a feature request, you are in the right place. Please keep the following in mind:

- This project is staffed by volunteers who work on it in their limited spare time. Please respect the volunteers' time and effort by being courteous and kind. Users who abuse the goodwill of the volunteers will be removed from the project and barred from making further comments.
- If you are looking for general technical help, please ensure you have read and understood the documentation for the software and standards this project builds upon. Issues that don't confirm that effort was taken to check the relevant documentation will be closed.
- If you wish to report a bug, please provide a single script that yields a complete standalone reproduction of the observed behavior, together with an explanation of the expected behavior and any citations that may be needed to support the expectation. Issues that don't provide this information will be closed.
- If you wish to make a feature request, please note that the maintainers' time is limited and you are invited to submit a pull request instead. Pull requests are expected to provide clean readable code, unit tests that cover the code and assert on the newly expected behavior, and documentation.
- If you are looking for support and using this library in a for-profit project, please donate using the "Sponsor" button above. If you are wondering how much to donate, you can use the rule of thumb of $100 per hour spent addressing your issue.

Thank you for contributing. You can delete this text to edit your issue content.

-->
